@@ -91,9 +91,6 @@ import Control.Lens
 import Control.Monad.State (StateT)
 import Data.Generics (Data, Typeable)
 import Data.Map as Map (Map)
-#if !MIN_VERSION_base(4,8,0)
-import Data.Monoid (Monoid(..))
-#endif
 import Data.Set as Set (insert, Set)
 import Data.Text (Text)
 import Debian.Changes (ChangeLog)
@@ -108,11 +105,7 @@ import Debian.Policy (PackageArchitectures, PackagePriority, Section, SourceForm
 import Debian.Relation (BinPkgName, Relations, SrcPkgName)
 import Debian.Version (DebianVersion)
 import Prelude hiding (init, init, log, log)
-#if MIN_VERSION_hsemail(2,0,0)
 import Text.Parsec.Rfc2822 (NameAddr)
-#else
-import Text.ParserCombinators.Parsec.Rfc2822 (NameAddr)
-#endif
 
 -- | Information required to represent a non-cabal debianization.
 data DebInfo
