@@ -157,7 +157,7 @@ finalizeDebianization' goodies date currentUser debhelperCompat setupExists =
 
 watchAtom :: PackageName -> Text
 watchAtom pkgname =
-    pack $ "version=3\nhttps://hackage.haskell.org/package/" ++ unPackageName pkgname ++ "/distro-monitor .*-([0-9\\.]+)\\.(?:zip|tgz|tbz|txz|(?:tar\\.(?:gz|bz2|xz)))\n"
+    pack $ "version=4\nhttps://hackage.haskell.org/package/" ++ unPackageName pkgname ++ "/distro-monitor .*-([0-9\\.]+)\\.(?:zip|tgz|tbz|txz|(?:tar\\.(?:gz|bz2|xz)))\n"
 
 -- | Compute the final values of the BinaryDebDescription record
 -- description fields from the cabal descriptions and the values that
@@ -405,13 +405,15 @@ finalizeChangelog date currentUser =
     where
       fixLog :: Maybe SrcPkgName -> V.DebianVersion -> Maybe [[Text]] -> Either String NameAddr -> Text -> Maybe ChangeLog -> Maybe ChangeLog
       -- Ensure that the package name is correct in the first log entry.
-      fixLog src ver cmts _maint _ (Just (ChangeLog (entry : older)))
+      fixLog src ver cmts _maint _ (Just (ChangeLog (entry@Entry{} : older)))
           | logVersion entry == ver =
               let entry' = entry { logPackage = show (pretty (PP src))
                                  , logComments = logComments entry ++ "\n" ++
                                                  (List.unlines $ List.map (("  * " <>) . List.intercalate "\n    " . List.map unpack) (fromMaybe [] cmts))
                                  } in
               Just (ChangeLog (entry' : older))
+      fixLog _src _ver _cmts _maint _ (Just (ChangeLog (entry@WhiteSpace{} : older))) =
+              Just (ChangeLog (entry : older))
       -- The newest log entry isn't exactly ver, build a new entry.
       fixLog src ver cmts maint msg log =
           let entry = Entry { logPackage = show (pretty (PP src))
@@ -461,7 +463,7 @@ officialSettings = do
 
         let packagesURI = "https://salsa.debian.org/haskell-team/DHG_packages/tree/master/p/" <> pack src
         zoom D.control $ do
-           S.standardsVersion .?= Just (parseStandardsVersion "4.6.1")
+           S.standardsVersion .?= Just (parseStandardsVersion "4.7.0")
            S.homepage .?= Just ("https://hackage.haskell.org/package/" <> pack (unPackageName cabal))
            S.vcsFields %= Set.union (Set.fromList
               [ S.VCSBrowser packagesURI
